/**
  *  \file game/selio.h
  *  \brief Saving and Loading Selection
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_SELIO_H
#define PCC_V2_GAME_SELIO_H

class TextFile;
class AnswerProvider;

/** Flags for saveSelection and loadSelection. */
enum {
    /** Timeless behaviour.
        - saveSelection: create a timeless file which will always be accepted as
          current by loadSelection
        - loadSelection: accept files with mismatching timestamp */
    selio_Timeless = 1,
    /** Accept files containing all selections.
        Handled by loadSelection only. */
    selio_AcceptAll = 2,
    /** Accept files containing a single selection.
        Handled by loadSelection only. */
    selio_AcceptSingle = 4,
    /** Accept files from the current turn.
        Handled by loadSelection only. */
    selio_AcceptCurrent = 8,
    /** Merge instead of replacing the current selection.
        Handled by loadSelection only. */
    selio_Merge         = 16
};

void saveSelection(TextFile& tf, int layer, int flags);
void loadSelection(TextFile& tf, int layer, int flags, AnswerProvider& answer);

#endif
