/**
  *  \file int/propenum.cc
  *  \brief Interpreter: Property Enumeration
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <cstring>
#include <cctype>
#include "int/propenum.h"
#include "int/if/ifutil.h"
#include "int/names.h"

/** Utility function: enumerate an IntVariableNames object.
    \param names Name list to enumerate */
void
IntPropertyAcceptor::enumNames(const IntVariableNames& names)
{
    for (IntVariableNames::index_t i = 0, e = names.getNumNames(); i < e; ++i) {
        addProperty(names.lookupAddress(i), thNone);
    }
}

/** Utility function: enumerate a TIntMapping array.
    \param map TIntMapping array
    \param size Number of items in array */
void
IntPropertyAcceptor::enumMapping(const TIntMapping* map, uint32_t size)
{
    for (uint32_t i = 0; i < size; ++i) {
        addProperty(map[i].name, TIntTypeHint(map[i].type));
    }
}

/** Beautify variable name. Converts UGLY.CAPS to Nicely.Formatted.Text. */
string_t
beautifyName(string_t name)
{
    bool hadUC = false;
    for (string_t::size_type i = 0; i < name.size(); ++i) {
        if (name[i] >= 'A' && name[i] <= 'Z') {
            if (hadUC) {
                name[i] = std::tolower(name[i]);
            } else {
                hadUC = true;
            }
        } else {
            hadUC = false;
        }
    }
    return name;
}
