/**
  *  \file u/t_game.h
  *  \brief Testsuite for game library (game/).
  *  \ingroup Testsuite
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_U_T_GAME_H
#define PCC_V2_U_T_GAME_H

#include <cxxtest/TestSuite.h> 
#include "u/helper.h"

class GameAttachmentConfigurationTestSuite : public CxxTest::TestSuite {
 public:
    void testSame();
    void testDifferent();
    void testRaceNameDefault();
    void testRaceNameAccept();
    void testRaceNameReject();
    void testEmpty();
};

class GameAttachmentUnpackerTestSuite : public CxxTest::TestSuite {
 public:
    void testInit();
    void testResult();
    void testResultDisabled();
    void testResult30();
    void testResultLeech();
    void testResultDamagedNames();
    void testUtilConfig();
    void testUtilFileGood();
    void testUtilFileTruncated();
    void testUtilFileName();
    void testUtilFileInvalidName();
    void testUtilFileInvalidName2();
    void testUtilFileInvalidName3();
    void testUtilFileBlacklistedName();
    void testUtilFileBlacklistedName2();
    void testUtilFileBlacklistedName3();
    void testUtilFileBlacklistedName4();
    void testUtilFileNameBorderCase();
    void testUtilFileNameBorderCase2();
    void testUtilFileMulti();
    void testUtilFileOrder();
    void testUtilFileOrder2();
    void testSave();
    void testSaveBlacklist();
    void testSaveBlacklistEnabled();
    void testDropUnchanged();
    void testDropUnchanged2();
    void testDropUnchanged3();
    void testDropUnchanged4();
    void testLoadDirectory();
    void testLoadDirectoryEmpty();
    void testToString();
    void testMultipleTimestamps();
    void testUtilLong();
    void testUtilLongShort();
    void testUtilLongBadLink();
    void testUtilLongBadLink2();
    void testUtilLongBadContent();
};

class GameChecksumTestSuite : public CxxTest::TestSuite {
 public:
    void testChecksum();
    void testDigest();
};

class GameCommandTestSuite : public CxxTest::TestSuite {
 public:
    void testCommands();
    void testMI();
    void testContainer();
    void testSequence();
};

class GameCoordTestSuite : public CxxTest::TestSuite {
 public:
    void testBasics();
    void testFlat();
    void testFlatSmall();
    void testFlatOffset();
    void testWrapped();
    void testWrappedSmall();
    void testParse();
    void testParseFail();
};

class GameCostTestSuite : public CxxTest::TestSuite {
 public:
    void testParse();
    void testAdd();             // +=
    void testSubtract();        // -=
    void testMult();            // *=, *
    void testCompare();         // ==, !=
    void testEnough();          // isEnoughFor()
};

class GameFcodeTestSuite : public CxxTest::TestSuite {
 public:
    void testFCode();
    void testRandom();
};

class GameHullfuncTestSuite : public CxxTest::TestSuite {
 public:
    void testHullFuncList();
};

class GameMissionTestSuite : public CxxTest::TestSuite {
 public:
    void testMissionIni();
    void testMissionIniRaces();
};

class GameMsgTemplateTestSuite : public CxxTest::TestSuite {
 public:
    void testValues();
    void testValuesX100();
    void testValuesEnum();
};

class GamePlanetPredTestSuite : public CxxTest::TestSuite {
 public:
    void testGrowthMaxTim();
    void testGrowthTholianTim();
    void testGrowthRebelTim();
    void testGrowthHumanoidTim();
};

class GamePlayerTestSuite : public CxxTest::TestSuite {
 public:
    void testParser();
};

class GamePlayerSetTestSuite : public CxxTest::TestSuite {
 public:
    void testMatrix();
    void testArray();
};

class GameRaceNameTestSuite : public CxxTest::TestSuite {
 public:
    void testRaceNameList();
};

class GameUfoTestSuite : public CxxTest::TestSuite {
    void doSingleMovementTest(int scan_x,
                              int expected_result,
                              int turns,
                              const char* name);
 public:
    void testMovementGuessing();
};

#endif
