/**
  *  \file unittest/t.io.glob.cc
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "io/glob.h"
#include "u/t_io.h"

void
IoGlobTestSuite::testGlob()
{
    {
        FileNamePattern m("foo*.*");
        TS_ASSERT(!m.match("foo"));
        TS_ASSERT(!m.match("foo1"));
        TS_ASSERT(m.match("foo."));
        TS_ASSERT(m.match("FOO."));
        TS_ASSERT(m.match("foobar.blub"));
        TS_ASSERT(m.match("foo.bar"));
    }

    {
        FileNamePattern m("*************************");
        TS_ASSERT(m.match(""));
        TS_ASSERT(m.match("xxxxxxxxxxxxxxxxxxxxxxxxxxx"));
    }

    {
        FileNamePattern m("*************************x");
        TS_ASSERT(!m.match(""));
        TS_ASSERT(m.match("xxxxxxxxxxxxxxxxxxxxxxxxxxx"));
        /* The following will take a lot of time if we don't
           optimise multiple '*' */
        TS_ASSERT(!m.match("yyyyyyyyyyyyyyyyyyyyyyyyyyy"));
    }

    {
        FileNamePattern m("*");
        TS_ASSERT(m.match(""));
        TS_ASSERT(m.match("a"));
        TS_ASSERT(m.match("aaaaaaaaaaa"));
        TS_ASSERT(m.match("*****"));
    }

    {
        FileNamePattern m("*a");
        TS_ASSERT(!m.match(""));
        TS_ASSERT(m.match("a"));
        TS_ASSERT(m.match("aaaaaaaaaaa"));
        TS_ASSERT(!m.match("*****"));
    }

    {
        FileNamePattern m("*?*?*?*?*?*?*?*?*?*?*?*?*?*");
        TS_ASSERT(!m.match(""));
        TS_ASSERT(!m.match("123456789ABC"));
        TS_ASSERT(m.match("123456789ABCD"));
        TS_ASSERT(m.match("123456789ABCDEFG"));
    }

    {
        FileNamePattern m("*?*?*?*?*?*?*?*?*?*?*?*?*?*x");
        TS_ASSERT(!m.match(""));
        TS_ASSERT(!m.match("123456789ABC"));
        TS_ASSERT(!m.match("123456789ABCD"));
        TS_ASSERT(!m.match("123456789ABCDEFG"));
        TS_ASSERT(!m.match("123456789ABCx"));
        TS_ASSERT(m.match("123456789ABCDx"));
        TS_ASSERT(m.match("123456789ABCDEFGx"));
    }

    {
        FileNamePattern m("*\\**");
        TS_ASSERT(!m.match("foo"));
        TS_ASSERT(!m.match(""));
        TS_ASSERT(m.match("foo*bar"));
    }

    {
        FileNamePattern m("a?b");
        TS_ASSERT(m.match("axb"));
        TS_ASSERT(!m.match("ab"));
        TS_ASSERT(!m.match("abc"));
        TS_ASSERT(!m.match("axbc"));
        TS_ASSERT(!m.match("axxb"));

        TS_ASSERT(m.match("a\xc2\x80""b"));
        TS_ASSERT(!m.match("ab"));
        TS_ASSERT(!m.match("abc"));
        TS_ASSERT(!m.match("a\xc2\x80""bc"));
        TS_ASSERT(!m.match("a\xc2\x80\xc2\x80""b"));
    }

    {
        FileNamePattern m("a??b");
        TS_ASSERT(!m.match("axb"));
        TS_ASSERT(!m.match("ab"));
        TS_ASSERT(!m.match("abc"));
        TS_ASSERT(!m.match("axbc"));
        TS_ASSERT(m.match("axxb"));

        TS_ASSERT(!m.match("a\xc2\x80""b"));
        TS_ASSERT(!m.match("ab"));
        TS_ASSERT(!m.match("abc"));
        TS_ASSERT(!m.match("a\xc2\x80""bc"));
        TS_ASSERT(m.match("a\xc2\x80\xc2\x80""b"));
    }
}
